@@ -57,19 +57,6 @@
   :type '(repeat function)
   :group 'irony-completion)
 
-(defcustom irony-completion-availability-filter '(available deprecated)
- "For completion, only accept candidates whose availability is in the list.
-
-Maps to libclang's CXAvailabilityKind:
-- https://clang.llvm.org/doxygen/group__CINDEX.html#gada331ea0195e952c8f181ecf15e83d71
-
-Due to a bug in
-Clang (https://bugs.llvm.org//show_bug.cgi?id=24329), candidates
-that can be validly accessed are deemed not-accessible."
- :type '(repeat symbol)
- :options '(available deprecated not-accessible)
- :group 'irony-completion)
-
 (defcustom irony-duplicate-candidates-filter nil
   "Remove duplicate candidates.
 
@@ -234,29 +221,24 @@ displayed when a derived class overrides virtual methods."
 (defun irony-completion-post-comp-placeholders (candidate)
   (cdr (nth 6 candidate)))
 
-(defun irony-completion-availability (candidate)
-  "See `irony-completion-availability-filter'"
-  (nth 7 candidate))
-
 (defun irony-completion--filter-candidates (candidates)
-  "Filter candidates based on availability (CXAvailabilityKind)
-first then remove any duplicates. Duplicate candidates are those
-that have the same `irony-completion-typed-text',
-`irony-completion-annotation' and `irony-completion-type'. An
-example of when this is useful is when there are many derived
-classes that override a virtual method resulting in redundant
-duplicate entries being displayed in the list of completions."
+  "Filter candidates by removing duplicates if
+`irony-duplicate-candidates-filter' is non nil; Duplicate
+candidates are those that have the same
+`irony-completion-typed-text', `irony-completion-annotation' and
+`irony-completion-type'. An example of when this is useful is
+when there are many derived classes that override a virtual
+method resulting in redundant duplicate entries being displayed
+in the list of completions."
   (let (unique-candidates)
     (cl-remove-if-not
      (lambda (candidate)
-       (and (memq (irony-completion-availability candidate)
-		   irony-completion-availability-filter)
-            (or (not irony-duplicate-candidates-filter)
-                (let ((unique-key (list (irony-completion-typed-text candidate)
-                                        (irony-completion-annotation candidate)
-                                        (irony-completion-type candidate))))
-                  (and (not (member unique-key unique-candidates))
-                       (push unique-key unique-candidates))))))
+       (or (not irony-duplicate-candidates-filter)
+           (let ((unique-key (list (irony-completion-typed-text candidate)
+                                   (irony-completion-annotation candidate)
+                                   (irony-completion-type candidate))))
+             (and (not (member unique-key unique-candidates))
+                  (push unique-key unique-candidates)))))
      candidates)))
 
 (defun irony-completion-candidates (&optional prefix style)
@@ -276,8 +258,7 @@ A candidate is composed of the following elements:
  6. Post-completion data. The text to insert followed by 0 or
     more indices. These indices work by pairs and describe ranges
     of placeholder text.
-    Example: (\"(int a, int b)\" 1 6 8 13)
- 7. The availability (CXAvailabilityKind) of the candidate." 
+    Example: (\"(int a, int b)\" 1 6 8 13)"
   (irony--awhen (irony-completion-symbol-bounds)
     (irony-completion--filter-candidates
      (irony--run-task
